@@ -8,7 +8,7 @@
 #' @return A list of bets and associated details 
 #' @export
 #' @importFrom jsonlite fromJSON
-#' @importFrom jsonlite rbind.pages
+#' @importFrom jsonlite rbind_pages
 #' @examples
 #' \donttest{
 #' SetCredentials("TESTAPI","APITEST")
@@ -17,25 +17,33 @@
 GetBetsList <-
   function(betids = NULL,
            betlist = c('SETTLED','RUNNING'),
-           fromDate = as.POSIXlt(Sys.Date(), tz = 'UTC')-15*24*60*60,
-           toDate = as.POSIXlt(Sys.Date(), tz = 'UTC')+24*60*60){
+           fromDate = as.POSIXlt(Sys.Date(), tz = 'UTC') - 15*24*60*60,
+           toDate = as.POSIXlt(Sys.Date(), tz = 'UTC') + 24*60*60){
     
     CheckTermsAndConditions()
     
-    jsonlite::rbind.pages(lapply(betlist, function(betlist_type) {
+    message(Sys.time(),
+      '| Pulling Bet list from Range: ', 
+      as.character(fromDate), ' to ', 
+      as.character(toDate)
+    )
+    
+    jsonlite::rbind_pages(lapply(betlist, function(betlist_type) {
         r <- GET(paste0(.PinnacleAPI$url ,"/v1/bets"),
-             add_headers(Authorization= authorization(),
+             add_headers(Authorization = authorization(),
                          "Content-Type" = "application/json"),
              query = 
                list(
-                 betlist=betlist_type,
-                 betids=
-                   if(!is.null(betids)) paste0(betids, collapse = ',') else NULL,
-                 fromDate=as.character(fromDate),
-                 toDate=as.character(toDate),
-                 appId = 'R')
+                 betlist = betlist_type,
+                 betids =
+                   if (!is.null(betids)) paste0(betids, collapse = ',') else NULL,
+                 fromDate = as.character(fromDate),
+                 toDate = as.character(toDate),
+                 appId = 'R'
+               )
              )
-        res <-  jsonlite::fromJSON(content(r,type="text"))
+        res <-  jsonlite::fromJSON(content(r,type = "text", encoding = "UTF-8"))
+
     
         as.data.frame(unlist(res, recursive = FALSE))
         }))
