@@ -23,17 +23,19 @@ GetSports <-
   function(force = TRUE) {
     CheckTermsAndConditions()
     # If Force = FALSE or the SportList is Empty then load a new Sport List
-    if(length(.PinnacleAPI$sports)==0 || force) {
-      sprintf("%s/v2/sports",.PinnacleAPI$url) %>%
-        GET(add_headers("Authorization"= authorization())) %>%
-        content(type = 'text') %>%
-        jsonlite::fromJSON() %>%
-        .[['sports']] %T>%
-        with({
-          .PinnacleAPI$sports <- .
-        })
+    if (length(.PinnacleAPI$sports) == 0 || force) {
+      
+      message(Sys.time(), "| Pulling Sports")
+
+      response <- httr::GET(paste0(.PinnacleAPI$url, "/v2/sports"),
+                            httr::add_headers(Authorization = authorization()),
+                            httr::accept_json())
+
+      CheckForAPIErrors(response)
+
+      response <- httr::content(response, type = "text", encoding = "UTF-8")
+      .PinnacleAPI$sports <- jsonlite::fromJSON(response)$sports
     }
-    
+
     .PinnacleAPI$sports
   }
-
